==> angular-ui-date-0.0.11.jar: META-INF/resources/webjars/angular-ui-date/0.0.11/CHANGELOG.md <==
<a name="0.0.11"></a>
## [0.0.11](https://github.com/Nexxa/ui-date/compare/0.0.10...v0.0.11) (2015-12-03)


### Bug Fixes

* **date:** Prevent jquery datepicker formatDate exception ([10c0e54](https://github.com/Nexxa/ui-date/commit/10c0e54)), closes [#48](https://github.com/Nexxa/ui-date/issues/48)



<a name="0.0.10"></a>
## [0.0.10](https://github.com/Nexxa/ui-date/compare/0.0.8...v0.0.10) (2015-11-26)


### Features

* **date:** common js support ([7e94737](https://github.com/Nexxa/ui-date/commit/7e94737))



<a name="0.0.8"></a>
## [0.0.8](https://github.com/Nexxa/ui-date/compare/0.0.7...0.0.8) (2015-06-11)


### Bug Fixes

* **setViewValue:** Don't lose time info on update ([af19760](https://github.com/Nexxa/ui-date/commit/af19760))



<a name="0.0.7"></a>
## [0.0.7](https://github.com/Nexxa/ui-date/compare/0.0.6...0.0.7) (2015-01-08)


### Bug Fixes

* **date:** destroy datepicker when element is removed ([26f36d2](https://github.com/Nexxa/ui-date/commit/26f36d2)), closes [#23](https://github.com/Nexxa/ui-date/issues/23) [#61](https://github.com/Nexxa/ui-date/issues/61) [#79](https://github.com/Nexxa/ui-date/issues/79)



<a name="0.0.6"></a>
## [0.0.6](https://github.com/Nexxa/ui-date/compare/0.0.5...0.0.6) (2014-11-12)




<a name="0.0.5"></a>
## [0.0.5](https://github.com/Nexxa/ui-date/compare/0.0.4...0.0.5) (2014-11-10)




<a name="0.0.4"></a>
## [0.0.4](https://github.com/Nexxa/ui-date/compare/0.0.3...0.0.4) (2014-08-06)


### Bug Fixes

* **setViewValue:** only update the model with the real date on blur ([5f24c7c](https://github.com/Nexxa/ui-date/commit/5f24c7c)), closes [#18](https://github.com/Nexxa/ui-date/issues/18)



<a name="0.0.3"></a>
## [0.0.3](https://github.com/Nexxa/ui-date/compare/0.0.2...0.0.3) (2013-06-19)




<a name="0.0.2"></a>
## [0.0.2](https://github.com/Nexxa/ui-date/compare/0.0.1...0.0.2) (2013-03-25)


### Bug Fixes

* **date-format:** should return null not undefined if viewValue is empty string ([3768719](https://github.com/Nexxa/ui-date/commit/3768719))



<a name="0.0.1"></a>
## [0.0.1](https://github.com/Nexxa/ui-date/compare/bcb1fd9...0.0.1) (2013-03-16)


### Bug Fixes

* **component:** Corrected path to main js file ([8947cfd](https://github.com/Nexxa/ui-date/commit/8947cfd))
* **date:** ensure date picker doesn't pop up again on IE ([2c62c92](https://github.com/Nexxa/ui-date/commit/2c62c92))
* **test:** remove unwanted dump() statement ([e8586e4](https://github.com/Nexxa/ui-date/commit/e8586e4))
* **tests:** Attempted to fix most tests and added new angular-module component ([b4d243d](https://github.com/Nexxa/ui-date/commit/b4d243d))
* **tests:** Forgot .travis.yml ([0bb9ed7](https://github.com/Nexxa/ui-date/commit/0bb9ed7))
* **tests:** Made build status clickable ([e77ca50](https://github.com/Nexxa/ui-date/commit/e77ca50))
* **ui.date module:** add [] to create module ([8581ede](https://github.com/Nexxa/ui-date/commit/8581ede))
* **uiDateConfig:** add directive specific config ([bcb1fd9](https://github.com/Nexxa/ui-date/commit/bcb1fd9))

### Features

* **tests:** Added image for build status ([aad7b9f](https://github.com/Nexxa/ui-date/commit/aad7b9f))

==> angular-ui-date-1.0.1.jar: META-INF/resources/webjars/angular-ui-date/1.0.1/CHANGELOG.md <==
<a name="1.0.1"></a>
## [1.0.1](https://github.com/angular-ui/ui-date/compare/1.0.0...v1.0.1) (2016-03-31)




<a name="1.0.0"></a>
# [1.0.0](https://github.com/angular-ui/ui-date/compare/1.0.0-beta.3...v1.0.0) (2016-02-18)


### Bug Fixes

* **ui-date:** Validator is ok for blank or null dates ([93e6141](https://github.com/angular-ui/ui-date/commit/93e6141))



<a name="1.0.0-beta.0"></a>
# [1.0.0-beta.0](https://github.com/angular-ui/ui-date/compare/0.0.11...v1.0.0-beta.0) (2015-12-09)

Update build to support umd and webpack.


<a name="0.0.11"></a>
## [0.0.11](https://github.com/Nexxa/ui-date/compare/0.0.10...v0.0.11) (2015-12-03)


### Bug Fixes

* **date:** Prevent jquery datepicker formatDate exception ([10c0e54](https://github.com/Nexxa/ui-date/commit/10c0e54)), closes [#48](https://github.com/Nexxa/ui-date/issues/48)



<a name="0.0.10"></a>
## [0.0.10](https://github.com/Nexxa/ui-date/compare/0.0.8...v0.0.10) (2015-11-26)


### Features

* **date:** common js support ([7e94737](https://github.com/Nexxa/ui-date/commit/7e94737))



<a name="0.0.8"></a>
## [0.0.8](https://github.com/Nexxa/ui-date/compare/0.0.7...0.0.8) (2015-06-11)


### Bug Fixes

* **setViewValue:** Don't lose time info on update ([af19760](https://github.com/Nexxa/ui-date/commit/af19760))



<a name="0.0.7"></a>
## [0.0.7](https://github.com/Nexxa/ui-date/compare/0.0.6...0.0.7) (2015-01-08)


### Bug Fixes

* **date:** destroy datepicker when element is removed ([26f36d2](https://github.com/Nexxa/ui-date/commit/26f36d2)), closes [#23](https://github.com/Nexxa/ui-date/issues/23) [#61](https://github.com/Nexxa/ui-date/issues/61) [#79](https://github.com/Nexxa/ui-date/issues/79)



<a name="0.0.6"></a>
## [0.0.6](https://github.com/Nexxa/ui-date/compare/0.0.5...0.0.6) (2014-11-12)




<a name="0.0.5"></a>
## [0.0.5](https://github.com/Nexxa/ui-date/compare/0.0.4...0.0.5) (2014-11-10)




<a name="0.0.4"></a>
## [0.0.4](https://github.com/Nexxa/ui-date/compare/0.0.3...0.0.4) (2014-08-06)


### Bug Fixes

* **setViewValue:** only update the model with the real date on blur ([5f24c7c](https://github.com/Nexxa/ui-date/commit/5f24c7c)), closes [#18](https://github.com/Nexxa/ui-date/issues/18)



<a name="0.0.3"></a>
## [0.0.3](https://github.com/Nexxa/ui-date/compare/0.0.2...0.0.3) (2013-06-19)




<a name="0.0.2"></a>
## [0.0.2](https://github.com/Nexxa/ui-date/compare/0.0.1...0.0.2) (2013-03-25)


### Bug Fixes

* **date-format:** should return null not undefined if viewValue is empty string ([3768719](https://github.com/Nexxa/ui-date/commit/3768719))



<a name="0.0.1"></a>
## [0.0.1](https://github.com/Nexxa/ui-date/compare/bcb1fd9...0.0.1) (2013-03-16)


### Bug Fixes

* **component:** Corrected path to main js file ([8947cfd](https://github.com/Nexxa/ui-date/commit/8947cfd))
* **date:** ensure date picker doesn't pop up again on IE ([2c62c92](https://github.com/Nexxa/ui-date/commit/2c62c92))
* **test:** remove unwanted dump() statement ([e8586e4](https://github.com/Nexxa/ui-date/commit/e8586e4))
* **tests:** Attempted to fix most tests and added new angular-module component ([b4d243d](https://github.com/Nexxa/ui-date/commit/b4d243d))
* **tests:** Forgot .travis.yml ([0bb9ed7](https://github.com/Nexxa/ui-date/commit/0bb9ed7))
* **tests:** Made build status clickable ([e77ca50](https://github.com/Nexxa/ui-date/commit/e77ca50))
* **ui.date module:** add [] to create module ([8581ede](https://github.com/Nexxa/ui-date/commit/8581ede))
* **uiDateConfig:** add directive specific config ([bcb1fd9](https://github.com/Nexxa/ui-date/commit/bcb1fd9))

### Features

* **tests:** Added image for build status ([aad7b9f](https://github.com/Nexxa/ui-date/commit/aad7b9f))
